# nonebot-plugin-osugreek

在图片上添加osu!mania 4k神秘希腊字母的 NoneBot2 插件

## 介绍

- 在图片中央贴上神秘的4k希腊字母
- 顺便添加色散视觉效果


## 安装
<details><summary> 本插件依赖以下库：</summary>
  
nonebot2 >= 2.0.0
  
Pillow >= 9.0.0

aiohttp >= 3.8.0


</details>

### 使用 nb-cli
留空

### pip
pip install nonebot-plugin-osugreek

### 从 GitHub 安装
https://github.com/YakumoZn/nonebot-plugin-osugreek.git


## 使用

### 基础命令
/osugreek <希腊字母名称>   /osugreek <希腊字母名称>
或
/希腊字母 <希腊字母名称>

### 使用方式
回复图片消息并输入：/osugreek <希腊字母名称>

<details> 
<summary>示例</summary>

![](https://i.ibb.co/xTL64vr/228922e3afd8a362ad5612a0645951b7.jpg)
*我得了一种看见希腊字母就会笑的病*
</details>

### 自定义字母
如果需要添加新的希腊字母，只需将 PNG 图片放入 images/ 目录
